==> quanyi-center-api-1.0.69-merge-20240527.021358-12-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/insurance/customer/RemoteInsuranceTakeRecordService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice.insurance.customer;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.insurance.customer.InsuranceTakeRecordDto;

import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 保司兑换记录表
 * @author kjj mybatis generator 
 * @date 2024-03-04
 */
@AdvancedFeignClient
public interface RemoteInsuranceTakeRecordService {

    /**
     * 当日已领取金额
     * @param accountPhone 手机号
     * @param spuType 商品类型
     * @see cn.com.duiba.quanyi.goods.service.api.enums.goods.SpuTypeEnum
     * @param now 当前时间
     * @return 金额
     */
    long sumDayAmount(String accountPhone, Integer spuType, Date now);

    /**
     * 当月已领取金额
     * @param accountPhone 手机号
     * @param spuType 商品类型
     * @see cn.com.duiba.quanyi.goods.service.api.enums.goods.SpuTypeEnum
     * @param now 当前时间
     * @return 金额
     */
    long sumMonthAmount(String accountPhone, Integer spuType, Date now);

    /**
     * 当日已领取金额
     * @param accountPhone 手机号
     * @param spuTypes 商品类型
     * @see cn.com.duiba.quanyi.goods.service.api.enums.goods.SpuTypeEnum
     * @param now 当前时间
     * @return key：商品类型，value：金额
     */
    Map<Integer, Long> sumDayAmountMap(String accountPhone, Set<Integer> spuTypes, Date now);

    /**
     * 当月已领取金额
     * @param accountPhone 手机号
     * @param spuTypes 商品类型
     * @see cn.com.duiba.quanyi.goods.service.api.enums.goods.SpuTypeEnum
     * @param now 当前时间
     * @return key：商品类型，value：金额
     */
    Map<Integer, Long> sumMonthAmountMap(String accountPhone, Set<Integer> spuTypes, Date now);

    /**
     * 分页查询兑换记录
     * @param lastId 上一页id，第一页不传
     * @param pageSize 分页大小
     * @param companyId 公司id
     * @param spuType 商品类型
     * @param userId 用户id
     * @return
     */
    List<InsuranceTakeRecordDto> selectByOffset(Long lastId, Integer pageSize, Long companyId, Integer spuType, Long userId);

    /**
     * 分页查询
     * @param lastId 最后一页id 第一页不传
     * @param pageSize 分页大小
     * @param companyId 公司id
     * @param spuType 商品类型
     * @param accountPhone 手机号
     * @return 保司兑换记录列表
     */
    List<InsuranceTakeRecordDto> selectByPhoneOffset(Long lastId, Integer pageSize, Long companyId, Integer spuType, String accountPhone);

    /**
     * 根据id查询
     * @param id
     * @return
     */
    InsuranceTakeRecordDto selectById(Long id);


    /**
     * 根据订单号查询
     * @param takeOrderNo
     * @return
     */
    InsuranceTakeRecordDto selectByTakeOrderNo(String takeOrderNo);



}

==> quanyi-center-api-1.1.25-merge-20240717.062821-41-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/insurance/customer/RemoteInsuranceTakeRecordService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice.insurance.customer;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.insurance.customer.InsuranceTakeRecordDto;

import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 保司兑换记录表
 * @author kjj mybatis generator 
 * @date 2024-03-04
 */
@AdvancedFeignClient
public interface RemoteInsuranceTakeRecordService {

    /**
     * 当日已领取金额
     * @param accountPhone 手机号
     * @param spuType 商品类型
     * @see cn.com.duiba.quanyi.goods.service.api.enums.goods.SpuTypeEnum
     * @param now 当前时间
     * @return 金额
     */
    long sumDayAmount(String accountPhone, Integer spuType, Date now);

    /**
     * 当月已领取金额
     * @param accountPhone 手机号
     * @param spuType 商品类型
     * @see cn.com.duiba.quanyi.goods.service.api.enums.goods.SpuTypeEnum
     * @param now 当前时间
     * @return 金额
     */
    long sumMonthAmount(String accountPhone, Integer spuType, Date now);

    /**
     * 当日已领取金额
     * @param accountPhone 手机号
     * @param spuTypes 商品类型
     * @see cn.com.duiba.quanyi.goods.service.api.enums.goods.SpuTypeEnum
     * @param now 当前时间
     * @return key：商品类型，value：金额
     */
    Map<Integer, Long> sumDayAmountMap(String accountPhone, Set<Integer> spuTypes, Date now);

    /**
     * 当月已领取金额
     * @param accountPhone 手机号
     * @param spuTypes 商品类型
     * @see cn.com.duiba.quanyi.goods.service.api.enums.goods.SpuTypeEnum
     * @param now 当前时间
     * @return key：商品类型，value：金额
     */
    Map<Integer, Long> sumMonthAmountMap(String accountPhone, Set<Integer> spuTypes, Date now);

    /**
     * 分页查询兑换记录
     * @param lastId 上一页id，第一页不传
     * @param pageSize 分页大小
     * @param companyId 公司id
     * @param spuType 商品类型
     * @param userId 用户id
     * @return
     */
    List<InsuranceTakeRecordDto> selectByOffset(Long lastId, Integer pageSize, Long companyId, Integer spuType, Long userId);

    /**
     * 分页查询
     * @param lastId 最后一页id 第一页不传
     * @param pageSize 分页大小
     * @param companyId 公司id
     * @param spuType 商品类型
     * @param accountPhone 手机号
     * @return 保司兑换记录列表
     */
    List<InsuranceTakeRecordDto> selectByPhoneOffset(Long lastId, Integer pageSize, Long companyId, Integer spuType, String accountPhone);

    /**
     * 根据id查询
     * @param id
     * @return
     */
    InsuranceTakeRecordDto selectById(Long id);


    /**
     * 根据订单号查询
     * @param takeOrderNo
     * @return
     */
    InsuranceTakeRecordDto selectByTakeOrderNo(String takeOrderNo);

    /**
     * 根据订单号批量查询
     * @param takeOrderNos 订单号集合
     * @return 兑换记录结果集
     */
    List<InsuranceTakeRecordDto> selectByTakeOrderNos(List<String> takeOrderNos);

}
